@@ -27,10 +27,10 @@
 #include <qplatformdefs.h> // QT_STATBUF, QT_LSTAT
 
 #include <QStack>
-#include <QtCore/QMap>
-#include <QtCore/QDebug>
-#include <QtCore/QDir>
-#include <QtCore/QFile>
+#include <QMap>
+#include <QDebug>
+#include <QDir>
+#include <QFile>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -124,8 +124,7 @@ bool KArchive::createDevice(QIODevice::OpenMode mode)
             if (!d->saveFile->open(QIODevice::WriteOnly)) {
                 setErrorString(
                     tr("QSaveFile creation for %1 failed: %2")
-                        .arg(d->fileName)
-                        .arg(d->saveFile->errorString()));
+                        .arg(d->fileName, d->saveFile->errorString()));
 
                 delete d->saveFile;
                 d->saveFile = nullptr;
@@ -263,8 +262,7 @@ bool KArchive::addLocalFile(const QString &fileName, const QString &destName)
     if (!file.open(QIODevice::ReadOnly)) {
         setErrorString(
             tr("Couldn't open file %1: %2")
-            .arg(fileName)
-            .arg(file.errorString()));
+            .arg(fileName, file.errorString()));
         return false;
     }
 
@@ -468,7 +466,16 @@ KArchiveDirectory *KArchive::findOrCreate(const QString &path)
             const KArchiveDirectory *dir = static_cast<const KArchiveDirectory *>(ent);
             return const_cast<KArchiveDirectory *>(dir);
         } else {
-            //qCWarning(KArchiveLog) << "Found" << path << "but it's not a directory";
+            const KArchiveFile *file = static_cast<const KArchiveFile *>(ent);
+            if (file->size() > 0) {
+                qCWarning(KArchiveLog) << path << "is normal file, but there are file paths in the archive assuming it is a directory, bailing out";
+                return nullptr;
+            }
+
+            qCDebug(KArchiveLog) << path << " is an empty file, assuming it is actually a directory and replacing";
+            KArchiveEntry *myEntry = const_cast<KArchiveEntry*>(ent);
+            rootDir()->removeEntry(myEntry);
+            delete myEntry;
         }
     }
 
@@ -827,8 +834,8 @@ const KArchiveFile *KArchiveDirectory::file(const QString &name) const
 void KArchiveDirectory::addEntry(KArchiveEntry *entry)
 {
     if (d->entries.value(entry->name())) {
-        /*qCWarning(KArchiveLog) << "directory " << name()
-                    << "has entry" << entry->name() << "already";*/
+        qCWarning(KArchiveLog) << "directory " << name()
+                    << "has entry" << entry->name() << "already";
         delete entry;
         return;
     }
